#ifndef memmap_h
#define memmap_h 1

struct mappedRegionS;
typedef struct mappedRegionS* mappedRegion; 

/* Map a file into the memory of this process.
 * Input parameters:
 *    path:   The name of the file to be mapped.
 *            The file is created if it doesn't exist.
 *    id:     A system wide unique identifier of the mapped region
 *    length: The length of the mapped region.
 *            This parameter is used only if the file doesn't exist, 
 *            otherwise the length of the existing file is used.
 * Output parameter:
 *    hReg:   A handle that describes the mapped region.
 * Return value:
 *    0: Successfull completion.
 *   -1: An error occured. The cause is specified in the variable errno.  
 *   -2: Not enough memory available.
 *   -3: An error occured. 
 *       The cause may be determined by GetLastError (Windows only).
 */
int memmap( const char* path, int id, int length, mappedRegion *hReg);

/* Unmap a file from the memory 
 * Input parameter:
 *    hReg:   The handle of the mapped region created by memmap
 */
void memunmap( mappedRegion *hReg);

/* Get the (local) address of a mapped region
 * Input parameter:
 *    hReg:   The handle of the mapped region created by memmap
 * Return value:
 *    The address
 */
char* memGetAddr( mappedRegion *hReg);

/* Get the length of a mapped region
 * Input parameter:
 *    hReg:   The handle of the mapped region created by memmap
 * Return value:
 *    The length in bytes
 */
int memGetLength( mappedRegion *hReg);

#endif
